==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/PetSetListFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import javax.validation.constraints.NotNull;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.model.ListMetaFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.ListMeta;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;
import javax.validation.Valid;
import java.lang.Object;
import lombok.ToString;
import java.util.Map;

public interface PetSetListFluent<A extends PetSetListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public A addToItems(PetSet... items);
    public A removeFromItems(PetSet... items);
    public List<PetSet> getItems();
    public A withItems(List<PetSet> items);
    public A withItems(PetSet... items);
    public PetSetListFluent.ItemsNested<A> addNewItem();
    public PetSetListFluent.ItemsNested<A> addNewItemLike(PetSet item);
    public String getKind();
    public A withKind(String kind);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public PetSetListFluent.MetadataNested<A> withNewMetadata();
    public PetSetListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public PetSetListFluent.MetadataNested<A> editMetadata();
    public PetSetListFluent.MetadataNested<A> editOrNewMetadata();
    public PetSetListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);
    public A withNewMetadata(String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PetSetFluent<PetSetListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<PetSetListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> kubernetes-model-1.0.63-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/PetSetListFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import javax.validation.constraints.NotNull;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.util.List;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Object;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ListMetaFluent;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;

public interface PetSetListFluent<A extends PetSetListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public A addToItems(PetSet... items);
    public A removeFromItems(PetSet... items);
    public List<PetSet> getItems();
    public A withItems(List<PetSet> items);
    public A withItems(PetSet... items);
    public PetSetListFluent.ItemsNested<A> addNewItem();
    public PetSetListFluent.ItemsNested<A> addNewItemLike(PetSet item);
    public String getKind();
    public A withKind(String kind);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public PetSetListFluent.MetadataNested<A> withNewMetadata();
    public PetSetListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public PetSetListFluent.MetadataNested<A> editMetadata();
    public A withNewMetadata(String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,PetSetFluent<PetSetListFluent.ItemsNested<N>>{

        
    public N endItem();    public N and();
}
    public interface MetadataNested<N> extends Nested<N>,ListMetaFluent<PetSetListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
